/****************************************************************************
 * OBIColumn header file                                                    *
 ****************************************************************************/

/**
 * @file obicolumn.h
 * @author Celine Mercier
 * @date 12 May 2015
 * @brief Header file for the shared elements of all the OBIColumn structures.
 */

#ifndef OBICOLUMN_H_
#define OBICOLUMN_H_

#include <stdio.h>


/**
 * @brief enum OBIDataType for the data type of the OBIColumns.
 */

typedef enum OBIDataType {
	OBI_VOID    = 0,     		/**< data type not specified */
	OBI_INT32,					/**< type int32_t */
	OBI_INT64,					/**< type int64_t */
	OBI_UINT32,					/**< type uint32_t */
	OBI_UNIT64,					/**< type uint64_t */
	OBI_STRING					/**< type char* */
} OBIDataType_t, *OBIDataType_p;


/**
 * @brief OBIColumnHeader structure.
 */

typedef struct OBIColumnHeader {
	bool			little_endian_order;    /**< endian byte order :
													 - True : little endian
													 - False: big endianx
	                                         */
	int				header_size_value;		/**< size of the header: a multiple of PAGESIZE */
	int				line_count;				/**< number of lines of data */
	OBIDataType_t	data_type;				/**< type of the data */
	char*			creation_date;			/**< date of creation of the file */
	int				version;				/**< version of the OBIColumn */
	char*			comments;				/**< comments */>
} OBIIntColumn_t, *OBIIntColumn_p;


#endif /* OBICOLUMN_H_ */
